# Utils

::: inspeqtor.utils

::: inspeqtor.utils.SyntheticDataModel

::: inspeqtor.utils.single_qubit_shot_quantum_device

::: inspeqtor.utils.finite_shot_quantum_device

::: inspeqtor.utils.get_measurement_probability

::: inspeqtor.utils.finite_shot_expectation_value

::: inspeqtor.utils.calculate_expectation_values

::: inspeqtor.utils.dictorization

::: inspeqtor.utils.random_split

::: inspeqtor.utils.dataloader

::: inspeqtor.utils.variance_of_observable

::: inspeqtor.utils.expectation_value_to_prob_plus

::: inspeqtor.utils.expectation_value_to_prob_minus

::: inspeqtor.utils.expectation_value_to_eigenvalue

::: inspeqtor.utils.eigenvalue_to_binary

::: inspeqtor.utils.binary_to_eigenvalue

::: inspeqtor.utils.recursive_vmap

::: inspeqtor.utils.calculate_shots_expectation_value

::: inspeqtor.utils.enable_jax_x64

::: inspeqtor.utils.disable_jax_x64

::: inspeqtor.utils.default_expectation_values_order

::: inspeqtor.utils.get_default_expectation_values_order

::: inspeqtor.utils.SX

::: inspeqtor.utils.X

::: inspeqtor.utils.Y

::: inspeqtor.utils.Z

::: inspeqtor.utils.plot_control_envelope

::: inspeqtor.utils.plot_expectation_values

::: inspeqtor.utils.assert_list_of_axes

::: inspeqtor.utils.set_fontsize

::: inspeqtor.utils.plot_loss_with_moving_average
